# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import user_api_pb2 as fsai__grpc__api_dot_protos_dot_user__api__pb2


class UserApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUser = channel.unary_unary(
                '/UserApi/CreateUser',
                request_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserResponse.FromString,
                )
        self.FindUserByEmail = channel.unary_unary(
                '/UserApi/FindUserByEmail',
                request_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailResponse.FromString,
                )
        self.AuthenticateUser = channel.unary_unary(
                '/UserApi/AuthenticateUser',
                request_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserResponse.FromString,
                )


class UserApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindUserByEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthenticateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserResponse.SerializeToString,
            ),
            'FindUserByEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.FindUserByEmail,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailResponse.SerializeToString,
            ),
            'AuthenticateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthenticateUser,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'UserApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/UserApi/CreateUser',
            fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_user__api__pb2.CreateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindUserByEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/UserApi/FindUserByEmail',
            fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_user__api__pb2.FindUserByEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthenticateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/UserApi/AuthenticateUser',
            fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_user__api__pb2.AuthenticateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import detection_instance_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2


class DetectionInstanceApiStub(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CacheDetectionInstancesDataByMissionImageId = channel.unary_unary(
                '/DetectionInstanceApi/CacheDetectionInstancesDataByMissionImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdResponse.FromString,
                )
        self.DeleteDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/DeleteDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
                )
        self.FindOrCreateDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.FromString,
                )
        self.GetDetectionInstanceDataById = channel.unary_stream(
                '/DetectionInstanceApi/GetDetectionInstanceDataById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
                )
        self.GetDetectionInstancesByMissionImageId = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstancesByMissionImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdResponse.FromString,
                )
        self.SetDetectionInstanceAsHumanVerified = channel.unary_unary(
                '/DetectionInstanceApi/SetDetectionInstanceAsHumanVerified',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.FromString,
                )
        self.TransitionDetectionInstanceState = channel.unary_unary(
                '/DetectionInstanceApi/TransitionDetectionInstanceState',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBbox = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
                )
        self.GetDetectionInstanceBboxById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceBboxById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
                )
        self.FindOrCreateShadowPointGeoPoints = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateShadowPointGeoPoints',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsResponse.FromString,
                )
        self.UpdateShadowPointGeoPointsById = channel.unary_unary(
                '/DetectionInstanceApi/UpdateShadowPointGeoPointsById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdResponse.FromString,
                )


class DetectionInstanceApiServicer(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    def CacheDetectionInstancesDataByMissionImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstancesByMissionImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDetectionInstanceAsHumanVerified(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransitionDetectionInstanceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceBboxById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateShadowPointGeoPoints(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateShadowPointGeoPointsById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CacheDetectionInstancesDataByMissionImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheDetectionInstancesDataByMissionImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdResponse.SerializeToString,
            ),
            'DeleteDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.SerializeToString,
            ),
            'FindOrCreateDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.SerializeToString,
            ),
            'GetDetectionInstanceDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDetectionInstanceDataById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.SerializeToString,
            ),
            'GetDetectionInstancesByMissionImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstancesByMissionImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdResponse.SerializeToString,
            ),
            'SetDetectionInstanceAsHumanVerified': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDetectionInstanceAsHumanVerified,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.SerializeToString,
            ),
            'TransitionDetectionInstanceState': grpc.unary_unary_rpc_method_handler(
                    servicer.TransitionDetectionInstanceState,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.SerializeToString,
            ),
            'GetDetectionInstanceBboxById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceBboxById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.SerializeToString,
            ),
            'FindOrCreateShadowPointGeoPoints': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateShadowPointGeoPoints,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsResponse.SerializeToString,
            ),
            'UpdateShadowPointGeoPointsById': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateShadowPointGeoPointsById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceApi(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    @staticmethod
    def CacheDetectionInstancesDataByMissionImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/CacheDetectionInstancesDataByMissionImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByMissionImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/DeleteDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DetectionInstanceApi/GetDetectionInstanceDataById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstancesByMissionImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstancesByMissionImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByMissionImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDetectionInstanceAsHumanVerified(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/SetDetectionInstanceAsHumanVerified',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransitionDetectionInstanceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/TransitionDetectionInstanceState',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceBboxById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceBboxById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateShadowPointGeoPoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateShadowPointGeoPoints',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateShadowPointGeoPointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateShadowPointGeoPointsById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateShadowPointGeoPointsById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateShadowPointGeoPointsByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
